define(
//begin v1.x content
({
	"findLabel": "Hľadať:",
	"findTooltip": "Zadajte text na nájdenie",
	"replaceLabel": "Nahradiť s:",
	"replaceTooltip": "Zadajte text na nahradenie",
	"findReplace": "Hľadať a nahradiť",
	"matchCase": "Rozlišovať veľkosť písmen",
	"matchCaseTooltip": "Rozlišovať veľkosť písmen",
	"backwards": "Dozadu",
	"backwardsTooltip": "Hľadať text dozadu",
	"replaceAllButton": "Nahradiť všetko",
	"replaceAllButtonTooltip": "Nahradiť všetok text",
	"findButton": "Hľadať",
	"findButtonTooltip": "Hľadať text",
	"replaceButton": "Nahradiť",
	"replaceButtonTooltip": "Nahradiť text",
	"replaceDialogText": "Nahradilo sa ${0} výskytov.",
	"eofDialogText": "Posledný výskyt ${0}",
	"eofDialogTextFind": "nájdený",
	"eofDialogTextReplace": "nahradený"
})

//end v1.x content
);
